Python Rook
==================

`Rook <http://www.rookout.com>`_ is a Python package that supports
on the fly debugging and data extraction from python applications
in production.

For more info see `Rookout's docs <https://docs.rookout.com/docs/python-setup>`_
